@@ -725,8 +725,12 @@ class VariableOsNvidiaMask(ReadonlyVariable):
                 chrootPath = image.getDirectory()
             else:
                 chrootPath = self.Get("cl_chroot_path")
-            nvidiaeclass = path.join(chrootPath,
-                                     'usr/portage/eclass/nvidia-driver.eclass')
+            if os.path.isdir('/var/db/repos/gentoo'):
+                nvidiaeclass = path.join(chrootPath,
+                                         'var/db/repos/gentoo/eclass/nvidia-driver.eclass')
+            else:
+                nvidiaeclass = path.join(chrootPath,
+                                         'usr/portage/eclass/nvidia-driver.eclass')
             if not os.access(nvidiaeclass, os.R_OK):
                 return ""
             #TODO investigate
